@@ -1,3 +1,16 @@
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+# implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import eventlet
 eventlet.monkey_patch(thread=False)
 
@@ -6,7 +19,7 @@ import unittest
 
 from ironicclient import exceptions
 from keystoneclient import exceptions as keystone_exc
-from mock import patch, Mock, ANY
+from mock import patch, Mock, ANY  # noqa
 
 from ironic_discoverd import client
 from ironic_discoverd import conf
